Documentation
¶
Overview ¶
Package runtime provides functionality for detecting and handling. Go runtime-specific directives and functions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsRuntimeHookFunction ¶
IsRuntimeHookFunction checks if a function name is a known runtime hook.
Types ¶
type DirectiveInfo ¶
type DirectiveInfo struct {
Type DirectiveType
Directive string
Valid bool
}
DirectiveInfo contains information about a runtime directive found on a function.
func HasRuntimeDirective ¶
func HasRuntimeDirective(fn *ast.FuncDecl) *DirectiveInfo
HasRuntimeDirective checks if a function declaration has any runtime directive.
type DirectiveType ¶
type DirectiveType int
DirectiveType represents different types of Go compiler directives.
const ( DirectiveNone DirectiveType = iota DirectiveNosplit DirectiveNoinline DirectiveNorace DirectiveNocheckptr DirectiveLinkname DirectiveCGoExport // CGo export directive )
Click to show internal directories.
Click to hide internal directories.